
/* --- menu items --- */

/**********************************************
each menu item is a block defined as follows:
   [
   		'Menu Name',
   		'Menu Link',
   		{ // extra config
   			'tw':'target window name',
   			'sb':'Status bar hint text',
   			'title':'Mouse-over title text',
   		}
   		// list of sub-menu items
   	],
where the menu link, and extra config can be replaced by null
and the submenu items are a list of menu items
Make sure the brackets match, and that there are commas after each item
***********************************************/




var MENU_ITEMS = [

/* **************************************************** */
	/* SageTV top-level menu */
	[
		'SageTV', 
		null, 
		null, /* extra config, eg target window, title text */

		/* submenu items */
		[
			'Home',
			'Home',
			{
				'title' :'Go to the SageTV Home page, with system information'
			}
		],
		[
			'Sage Recordings',
			'Recordings',
			{
				'title' :'View the list of recorded TV files'
			},
		],
		[
			'Search Recorded TV files',
			'Search?searchType=TVFiles&sort1=title_asc&sort2=airdate_asc',
			{
				'title' :'Search the recorded TV files'
			}
		],
		[
			'Web Remote (Local Sage)',
			'webremote.html?context=SAGETV_PROCESS_LOCAL_UI&contextname=Local%20SageTV',
			{
				'title' :'Control SageTV from a web browser',
				'tw': 'webremote'
			},
		],
		[
			'About',
			'about.html',
			{
				'title' :'Show licence, version info and credits'
			}
		],
	],
/* **************************************************** */
/* Schedule Recordings */
	[
		'Schedule Recordings',
		null,
		null,

		/* submenu items */
		[
			'Upcoming Recordings',
			'RecordingSchedule',
			{
				'title' :'Show the list of recordings scheduled to occur in the future'
			}
		],
		[
			'Intelligent Suggestions',
			'IRSuggestions',
			{
				'title' :'Show the list of Intelligent Recordings scheduled to occur in the future'
			}
		],
		[
			'Favorites Manager',
			'Favorites',
			{
				'title' :'View/Edit the Favorites defined in Sage'
			},
		],
		[
			'Timed Recording',
			'TimedRecord',
			{
				'title' :'Set up a recording to occur on a specific channel at a specific time'
			}
		],
		[
			'Recording Conflicts',
			'Conflicts',
			{
				'title' :'View the list of shows that will not be recorded due to conflicts with other scheduled recordings'
			}
		],				
	],
/* **************************************************** */
/* Program Guide Menu */
	[
		'Program Guide',
		null,
		null,

		/* submenu items */
		[
			'EPG List view',
			'EpgList',
			{
				'title' :'Show the Program Guide in list format'
			}
		],
		[
			'EPG Grid view',
			'EpgGrid',
			{
				'title' :'Show the Program Guide in Grid format'
			}
		],
		[
			'Search EPG',
			'Search',
			{
				'title' :'Search the Program Guide'
			}
		],
/* examples of shortcuts to specific epg views */
		[
			'Today PrimeTime',
			'EpgGrid?starthr=18',
			{
				'title' :'Show the EPG Grid view for today at 18:00h'
			}
		],
		[
			'Tomorrow PrimeTime',
			'EpgGrid?starthr=18&startdate=1',
			{
				'title' :'Show the EPG Grid view for tomorrow at 18:00h'
			}
		],
/* examples of shortcuts to specific searches */
		[
			'Upcoming movies',
			'Search?TimeRange=48&Categories=film&Categories=movie&Categories=Movie&SearchString=',
			{
				'title' :'Search the EPG for movies occuring in the next 48 hrs'
			}
		],
		[
			'Upcoming Favorites',
			'Search?TimeRange=48&favorite=set&SearchString=',
			{
				'title' :'Search the EPG for favorites occuring in the next 48 hrs'
			}
		],
/* EPG Db searches */
		[
			'Watched Shows',
			'Search?SearchString=&searchType=Airings&TimeRange=-1&watched=set&sort1=airdate_desc&sort2=none',
			{
				'title' :'Search the Sage DB for all shows that have been marked as watched'
			}
		],
		[
			'Don\'t like Shows',
			'Search?SearchString=&searchType=Airings&TimeRange=-1&dontlike=set&sort1=title_asc&sort2=airdate_asc',
			{
				'title' :'Search the Sage DB for all shows that have been marked as Don\'t Like'
			}
		],
	],
/* **************************************************** */
/* Media Library Menu */
	[
		'Media Library',
		null,
		null,
		[
			'Search DVDs',
			'Search?searchType=MediaFiles&DVD=on&sort1=title_asc&sort2=none',
			{
				'title' :'Search the Media Library for imported DVDs'
			}
		],
		[
			'Search Imported Videos',
			'Search?searchType=MediaFiles&Video=on&sort1=title_asc&sort2=none',
			{
				'title' :'Search the Media Library for Video Files'
			}
		],
		[
			'Search Music by track Title',
			'Search?searchType=MediaFiles&Music=on&search_fields=episode&sort1=episode_asc&sort2=none',
			{
				'title' :'Search the Media Library for Music Files matching the track title'
			}
		],
		[
			'Search Music by Artist',
			'Search?searchType=MediaFiles&Music=on&search_fields=people&sort1=people_asc&sort2=episode_asc',
			{
				'title' :'Search the Media Library for Music Files matching the Artist Name'
			}
		],
		[
			'Search Music by Album',
			'Search?searchType=MediaFiles&Music=on&search_fields=title&sort1=title_asc&sort2=episode_asc',
			{
				'title' :'Search the Media Library for Music Files matching the Album Name'
			}
		],
		[
			'Search Music by Genre',
			'Search?searchType=MediaFiles&Music=on&search_fields=category&sort1=title_asc&sort2=episode_asc',
			{
				'title' :'Search the Media Library for Music Files matching the Category'
			}
		],		
		[
			'Search Picture Files',
			'Search?searchType=MediaFiles&Picture=on&sort1=title_asc&sort2=none',
			{
				'title' :'Search the Media Library for Picture Files'
			}
		],
		[
			'Export Playlists',
			'PlaylistGenerator?Command=list',
			{
				'title' :'Export playlists from SageTV'
			}
		],
	],
/* **************************************************** */
/* Add other top-level menus here... */
];
